@@ -190,7 +190,8 @@ int harmless(SMFICTX *ctx, struct mlfiPriv *priv)
     // get from ptiv
     struct mailinfo *minfo = priv->mlfi_minfo;
     struct config *cfg = priv->mlfi_conf;
-    struct rcptaddr *rcptlist = priv->mlfi_rdmpasslist->rcptlist;
+    struct rcptinfo *p;
+    struct rcptaddr *rdm_all = NULL;
 
     // 無害化関数に渡す引数
     harmless_proc_arg_t proc_arg;
@@ -295,7 +296,7 @@ int harmless(SMFICTX *ctx, struct mlfiPriv *priv)
             }
         }
 
-        _ret = convert_zip(cfg, &mz, &rinfo_list);
+        _ret = convert_zip(cfg, &mz, rinfo_list);
         if (_ret == -1) {
             free(mz.encfilepath);
             free(mz.attachfilename);
@@ -380,17 +381,31 @@ HARMLESS_ZIP_LOG,
 
     free_harmless_proc_arg(&proc_arg);
 
-    // 新メールを送信する
-    ret = sendmail_with_gmime_object(msg_org, cfg, rcptlist, priv->mlfi_savefrom);
-
-    // milterに送信済みの人を消してもらう
-    for (i = 0; (rcptlist + i)->rcpt_addr != NULL; i++) {
-        if (smfi_delrcpt(ctx, (rcptlist + i)->rcpt_addr) == MI_FAILURE) {
-            //log(); // TODO
-            goto fail;
+    /* 送信先リストの作成 */
+    for (p = priv->mlfi_rdmpasslist; p != NULL; p = p->Next) {
+        for (i = 0; (p->rcptlist + i)->rcpt_addr; i++) {
+            if (push_rcptlist(&rdm_all, (p->rcptlist + i)->rcpt_addr) != 0) {
+                free_rcptlist(rdm_all);
+                goto fail;
+            }
         }
     }
 
+    // 新メールを送信する
+    ret = sendmail_with_gmime_object(msg_org, cfg, rdm_all, priv->mlfi_savefrom);
+
+    // milterに送信済みの人を消してもらう
+    for (i = 0; (rdm_all + i)->rcpt_addr != NULL; i++) {
+        if (smfi_delrcpt(ctx, (rdm_all + i)->rcpt_addr) == MI_FAILURE) {
+            //log(); // TODO
+            free_rcptlist(rdm_all);
+            goto fail;
+        } 
+    }
+
+    /* 送信先リストの開放 */
+    free_rcptlist(rdm_all);
+
     goto end;
 
 
