@@ -27,22 +27,22 @@
 
 //log format
 #define ERR_HARM_QUERYFAILURE   "Failed to query DNS.: source=%s, message-id=%s, sender=%s, recipients=%s\n"
-#define ERR_HARM_SPFQUERYFAILURE   "Failed to query DNS(SPF).: source=%s, message-id=%s, sender=%s, recipients=%s\n"
+#define ERR_HARM_SPFQUERYFAILURE   "Failed to query SPF record.: source=%s, message-id=%s, sender=%s, recipients=%s\n"
 #define ERR_HARM_DOMAINQUERYFAILURE_A  "Failed to query A record.: source=%s, message-id=<%s>, sender=%s, recipients=%s\n"
 #define ERR_HARM_DOMAINQUERYFAILURE_MX "Failed to query MX record.: source=%s, message-id=<%s>, sender=%s, recipients=%s\n"
-#define ERR_HARM_SPFNEUTRAL   "Failed to query DNS(spf:neutral).: source=%s, message-id=%s, sender=%s, recipients=%s\n"
-#define ERR_HARM_SPFPERM   "Failed to query DNS(spf:permerror).: source=%s, message-id=%s, sender=%s, recipients=%s\n"
-#define ERR_HARM_SPFFAIL   "Failed to query DNS(spf:fail).: source=%s, message-id=%s, sender=%s, recipients=%s\n"
-#define ERR_HARM_SPFSOFT   "Failed to query DNS(spf:softfail).: source=%s, message-id=%s, sender=%s, recipients=%s\n"
-#define ERR_HARM_SPFINV   "Failed to query DNS(spf:invalid).: source=%s, message-id=%s, sender=%s, recipients=%s\n"
-#define ERR_HARM_NAMENOTFOUND   "No PTR record in DNS.: source=%s, message-id=%s, sender=%s, recipients=%s\n"
+#define ERR_HARM_DOMAINQUERYFAILURE_AAAA  "Failed to query AAAA record.: source=%s, message-id=<%s>, sender=%s, recipients=%s"
+
+#define NG_HARM_SPFNEUTRAL   "SPF NG (neutral).: source=%s, message-id=%s, sender=%s, recipients=%s\n"
+#define NG_HARM_SPFPERM   "SPF NG (permerror).: source=%s, message-id=%s, sender=%s, recipients=%s\n"
+#define NG_HARM_SPFFAIL   "SPF NG (fail).: source=%s, message-id=%s, sender=%s, recipients=%s\n"
+#define NG_HARM_SPFSOFT   "SPF NG (softfail).: source=%s, message-id=%s, sender=%s, recipients=%s\n"
+#define NG_HARM_SPFINV   "SPF NG (invalid).: source=%s, message-id=%s, sender=%s, recipients=%s\n"
+#define NG_HARM_NAMENOTFOUND   "No PTR record in DNS.: source=%s, message-id=%s, sender=%s, recipients=%s\n"
 #define OK_HARM_SENDER_IP       "Sender IPaddress OK.: source=%s, message-id=%s, sender=%s, recipients=%s\n"
 #define NG_HARM_SENDER_IP       "Sender NG.: source=%s, message-id=%s, sender=%s, recipients=%s\n"
 
-#define ERR_HARM_SPFNOTFOUND   "No SPF record in DNS.: source=%s, message-id=%s, sender=%s, recipients=%s\n"
+#define NG_HARM_SPFNOTFOUND   "No SPF record in DNS.: source=%s, message-id=%s, sender=%s, recipients=%s\n"
 #define OK_HARM_SPF       "SPF OK.: source=%s, message-id=<%s>, sender=%s, recipients=%s\n"
-#define NG_HARM_SPF       "SPF NG.: source=%s, message-id=%s, sender=%s, recipients=%s\n"
-
 
 #define OK_HARM_SENDER_DOMAIN_A   "A record check OK.: source=%s, message-id=<%s>, sender=%s, recipients=%s\n"
 #define OK_HARM_SENDER_DOMAIN_MX  "MX record check OK.: source=%s, message-id=<%s>, sender=%s, recipients=%s\n"
@@ -53,7 +53,6 @@
 #define OK_HARM_SENDER_DOMAIN_AAAA   "AAAA record check OK.: source=%s, message-id=<%s>, sender=%s, recipients=%s\n"
 #define NO_HARM_SENDER_DOMAIN_AAAA   "No AAAA record in DNS.: source=%s, message-id=%s, sender=%s, recipients=%s\n"
 #define NG_HARM_SENDER_DOMAIN_AAAA   "AAAA record check NG.: source=%s, message-id=<%s>, sender=%s, recipients=%s\n"
-#define ERR_HARM_DOMAINQUERYFAILURE_AAAA  "Failed to query AAAA record.: source=%s, message-id=<%s>, sender=%s, recipients=%s\n"
 
 #define NG_HARMLESS       "harmless: source=%s, message-id=%s, sender=%s, recipients=%s\n"
 
